agentidentity

package
v0.28.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package agentidentity generates opaque identifiers for durable Orc agents and their individual live process instances.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewAgentID

func NewAgentID() (string, error)

NewAgentID returns a durable identity that survives provider resumes.

func NewInstanceID

func NewInstanceID() (string, error)

NewInstanceID returns the identity of one live agent process launch.

Types

This section is empty.

Jump to